ref: 45244f80434ade2110b541e106da0322bb9988c1
parent: 69d1a3609e207e2666ac3f67eb1798408ce8f5eb
author: Werner Lemberg <[email protected]>
date: Tue Dec 10 08:18:11 EST 2013
[autofit] s/AF_SCRIPT_NONE/AF_SCRIPT_UNASSIGNED/.
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,5 +1,9 @@
2013-12-10 Werner Lemberg <[email protected]>
+ [autofit] s/AF_SCRIPT_NONE/AF_SCRIPT_UNASSIGNED/.
+
+2013-12-10 Werner Lemberg <[email protected]>
+
[truetype] Fix scaling of vertical phantom points.
* src/truetype/ttgload.c (load_truetype_glyph): Scale pp3.x and
--- a/src/autofit/afglobal.h
+++ b/src/autofit/afglobal.h
@@ -51,9 +51,9 @@
#define AF_SCRIPT_FALLBACK AF_SCRIPT_DFLT
#endif
/* a bit mask indicating an uncovered glyph */
-#define AF_SCRIPT_NONE 0x7F
+#define AF_SCRIPT_UNASSIGNED 0x7F
/* if this flag is set, we have an ASCII digit */
-#define AF_DIGIT 0x80
+#define AF_DIGIT 0x80
/* `increase-x-height' property */
#define AF_PROP_INCREASE_X_HEIGHT_MIN 6
--- a/src/autofit/afglobal.c
+++ b/src/autofit/afglobal.c
@@ -88,9 +88,9 @@
FT_UInt i;
/* the value AF_SCRIPT_NONE means `uncovered glyph' */
FT_MEM_SET( globals->glyph_scripts,
- AF_SCRIPT_NONE,
+ AF_SCRIPT_UNASSIGNED,
globals->glyph_count );
error = FT_Select_Charmap( face, FT_ENCODING_UNICODE );
@@ -128,9 +128,9 @@
gindex = FT_Get_Char_Index( face, charcode );
- if ( gindex != 0 &&
- gindex < (FT_ULong)globals->glyph_count &&
- gscripts[gindex] == AF_SCRIPT_NONE )
+ if ( gindex != 0 &&
+ gindex < (FT_ULong)globals->glyph_count &&
+ gscripts[gindex] == AF_SCRIPT_UNASSIGNED )
gscripts[gindex] = (FT_Byte)ss;
for (;;)
@@ -140,8 +140,8 @@
if ( gindex == 0 || charcode > range->last )
break;
- if ( gindex < (FT_ULong)globals->glyph_count &&
- gscripts[gindex] == AF_SCRIPT_NONE )
+ if ( gindex < (FT_ULong)globals->glyph_count &&
+ gscripts[gindex] == AF_SCRIPT_UNASSIGNED )
gscripts[gindex] = (FT_Byte)ss;
}
}
@@ -162,7 +162,7 @@
* By default, all uncovered glyphs are set to the fallback script.
* XXX: Shouldn't we disable hinting or do something similar?
*/
- if ( globals->module->fallback_script != AF_SCRIPT_NONE )
+ if ( globals->module->fallback_script != AF_SCRIPT_UNASSIGNED )
{
FT_Long nn;
@@ -169,9 +169,9 @@
for ( nn = 0; nn < globals->glyph_count; nn++ )
{
- if ( ( gscripts[nn] & ~AF_DIGIT ) == AF_SCRIPT_NONE )
+ if ( ( gscripts[nn] & ~AF_DIGIT ) == AF_SCRIPT_UNASSIGNED )
{
- gscripts[nn] &= ~AF_SCRIPT_NONE;
+ gscripts[nn] &= ~AF_SCRIPT_UNASSIGNED;
gscripts[nn] |= globals->module->fallback_script;
}
}
@@ -277,7 +277,8 @@
/* if we have a forced script (via `options'), use it, */
/* otherwise look into `glyph_scripts' array */
if ( script == AF_SCRIPT_DFLT || script + 1 >= AF_SCRIPT_MAX )
- script = (AF_Script)( globals->glyph_scripts[gindex] & AF_SCRIPT_NONE );
+ script = (AF_Script)( globals->glyph_scripts[gindex] &
+ AF_SCRIPT_UNASSIGNED );
script_class = AF_SCRIPT_CLASSES_GET[script];
writing_system_class = AF_WRITING_SYSTEM_CLASSES_GET
@@ -88,9 +88,9 @@
FT_UInt i;
- /* the value AF_SCRIPT_NONE means `uncovered glyph' */
+ /* the value AF_SCRIPT_UNASSIGNED means `uncovered glyph' */
FT_MEM_SET( globals->glyph_scripts,